#[interceptor]Expand description
Applies the interceptor to the current scope.
This macro can be used to apply an Interceptor to different Adapter types,
such as REST controllers or Socket.IO adapters.
#[interceptor]Applies the interceptor to the current scope.
This macro can be used to apply an Interceptor to different Adapter types,
such as REST controllers or Socket.IO adapters.