Defines a configuration struct for the application.
This macro generates the necessary code to deserialize the struct from
the configuration toml file.
Defines a Sword controller.
Route handlers are declared directly inside the impl block using method attributes
such as #[get], #[post], #[put], #[patch], #[delete], #[head], #[options], #[trace], and #[connect].
Marks a route or controller with one or more interceptors.
This macro can be used to apply an Interceptor to different controller kinds,
such as web controllers or Socket.IO controllers.