#[interceptor]Expand description
Marks a route or controller with one or more interceptors.
This macro can be used to apply an Interceptor to different controller kinds,
such as web controllers or Socket.IO controllers.
#[interceptor]Marks a route or controller with one or more interceptors.
This macro can be used to apply an Interceptor to different controller kinds,
such as web controllers or Socket.IO controllers.